@@ -102,9 +102,9 @@ sub new {
         features => {},
         pure_perl => 0,
         cpanfile_path => 'cpanfile',
+        @_,
     }, $class;
 
-    $self->parse_options(@_);
     $self;
 }
 
